@@ -17,6 +17,10 @@ from django.views.generic import DetailView
 
 class FlatpageDetailView(DetailView):
 
+    # template_name=model.objects.get()
+    # page = get_object_or_404(mymodels.Pages, slug=self.kwargs['render_template']);
+    # template_name = page.template_name
+
     template_name = "rflatpages/default.html"
     context_object_name = "myflatpage"
 
@@ -36,3 +40,12 @@ class FlatpageDetailView(DetailView):
         context.update({
         })
         return context
+
+    def get_template_names(self):
+        """
+         `get_object` has already set this attribute, so we pick up the
+         template from the model. I it doesn't exists we pick up the
+         super name.
+        """
+        templates = [self.obj.template]
+        return templates + super(FlatpageDetailView, self).get_template_names()
\ No newline at end of file
